@@ -29,6 +29,8 @@ class AndroidApi:
     ANDROID_API_USERNAME = base64.b64decode('QzIzMzFDRDYtRDQ1MC00OTVFLTlDMTktNjcyMTUyMzBDODVD').decode()
     ANDROID_API_PASSWORD = base64.b64decode('dHo0MzNLVzVRREM5VjdmIXo2QF4ybyZZNlNHR1lo').decode()
 
+    ANDROID_USER_AGENT = 'Dalvik/2.1.0 (Linux; U; Android 12; Pixel 4a Build/SP2A.220305.012)'
+
     # These tokens are separate from the "standard" tdcservices API
     accessToken = None
     accessTokenExpiresAt = None
@@ -51,7 +53,10 @@ class AndroidApi:
                 'grant_type': 'password',
                 'scope': self.OAUTH_SCOPES
             },
-            headers={'Content-Type': 'application/x-www-form-urlencoded'},
+            headers={
+                'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
+                'User-Agent': self.ANDROID_USER_AGENT
+            },
             auth=requests.auth.HTTPBasicAuth(self.ANDROID_API_USERNAME, self.ANDROID_API_PASSWORD)
         )
 
@@ -82,7 +87,11 @@ class AndroidApi:
         return {'Authorization': 'Bearer %s' % self.accessToken}
 
     def _get(self, endpoint, query={}, **kwargs):
-        r = requests.get(self.BASE_URL + endpoint, query, headers=self.api_headers(), **kwargs)
+        r = requests.get(self.BASE_URL + endpoint, query, headers={
+            'User-Agent': self.ANDROID_USER_AGENT,
+            'Content-Type': 'application/json',
+            **self.api_headers()
+        }, **kwargs)
 
         if r.status_code != 200:
             raise ApiException(r.status_code, "Android API HTTP %s response: %s" % (str(r.status_code), r.text))
@@ -134,6 +143,9 @@ class AndroidApi:
     # TODO: these methods are used in the web app, not the Android app,
     # but support the same auth tokens and are on this domain. They should
     # be moved to a new Api class.
+    # 3/17/2022: the API appears to be more stringently checking scopes,
+    # and some of these endpoints no longer work with the API token scoped
+    # to the Android app.
 
     """
     Returns BG and pump threshold values.
@@ -154,16 +166,3 @@ class AndroidApi:
     """
     def user_profile(self):
         return self.get('cloud/usersettings/api/UserProfile?userId=%s' % self.userId)
-    
-    """
-    Returns therapy events, used by the webui Therapy Timeline.
-    {'event': [
-      {'type': 'Basal', 'basalRate': ...}, 
-      {'type': 'Bolus', 'standard': ...},
-      {'type': 'CGM', 'egv': ...}
-    ]}
-    """
-    def therapy_events(self, start_date=None, end_date=None):
-        startDate = parse_date(start_date)
-        endDate = parse_date(end_date)
-        return self.get('tconnect/therapyevents/api/TherapyEvents/%s/%s/false?userId=%s' % (startDate, endDate, self.userId))
